#
# spec file for package mathomatic
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mathomatic
Version:        16.0.4
Release:        11.3
Summary:        Computer algebra system
License:        LGPL-2.1
Group:          Productivity/Scientific/Math

Url:            http://www.mathomatic.org/
Source:         http://www.mathomatic.org/archive/mathomatic-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  readline-devel
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
Requires:       m4
# BuildArch:      noarch

Source1:        mathomatic.desktop
ExcludeArch:    ppc64

%description
Mathomatic is a free, portable, general-purpose Computer Algebra System (CAS)
that can automatically solve, differentiate, simplify, combine, and compare
algebraic equations, perform standard, complex number, modular, and polynomial
arithmetic, etc. It does some calculus and is very easy to learn and use.
Plotting expressions with gnuplot is also supported. This package
is complete, including Mathomatic, the Prime Number Tools, m4 Mathomatic,
and all documentation.

Author:
-------
    George Gesslein II <gesslein@mathomatic.org>

%package devel
Summary:        Development Package for Mathomatic
Group:          Development/Libraries/C and C++

%description devel
This package contains the Mathomatic symbolic math library, for using the
Mathomatic code inside of any C compatible program.  This is a static
library only, with no dependencies or requirements.  It has a small, easy
to use API that is written in C.  The Mathomatic code is not re-entrant.

Author:
-------
    George Gesslein II <gesslein@mathomatic.org>

%prep
%setup -q

%build
make OPTFLAGS="$RPM_OPT_FLAGS" %{?_smp_mflags} READLINE=1
make -C primes OPTFLAGS="$RPM_OPT_FLAGS" %{?_smp_mflags}
make -C lib OPTFLAGS="$RPM_OPT_FLAGS -g" %{?_smp_mflags} lib

%check
make check
make -C primes check bigcheck

%install
make bininstall matho-rmath-install DESTDIR=%{buildroot} prefix=%{_prefix} docdir=%{_docdir} datadir=%{_datadir}
install -D -m 644 %{SOURCE1} %{buildroot}/%{_datadir}/applications/mathomatic.desktop
%if 0%{?suse_version}
%suse_update_desktop_file -n mathomatic
%endif
make -C primes install DESTDIR=%{buildroot} prefix=%{_prefix}
make -C lib install DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{_libdir} includedir=%{_includedir}
make -C lib distclean

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc examples tests
%doc README.txt AUTHORS COPYING NEWS doc
%{_mandir}/man1/mathomatic.1*
%{_mandir}/man1/matho.1*
%{_mandir}/man1/rmath.1*
%{_mandir}/man1/matho-primes.1*
%{_mandir}/man1/matho-pascal.1*
%{_mandir}/man1/matho-sumsq.1*
%{_mandir}/man1/primorial.1*
%{_mandir}/man1/matho-mult.1*
%{_mandir}/man1/matho-sum.1*
%{_datadir}/%{name}
%{_bindir}/mathomatic
%{_bindir}/matho
%{_bindir}/rmath
%{_bindir}/matho-primes
%{_bindir}/matho-pascal
%{_bindir}/matho-sumsq
%{_bindir}/primorial
%{_bindir}/matho-mult
%{_bindir}/matho-sum
%{_datadir}/pixmaps/mathomatic.*
%{_datadir}/applications/mathomatic.desktop

%files devel
%defattr(-,root,root,-)
%doc lib
%{_mandir}/man3/matho_init.3*
%{_mandir}/man3/matho_clear.3*
%{_mandir}/man3/matho_parse.3*
%{_mandir}/man3/matho_process.3*
%{_libdir}/libmathomatic.a
%{_includedir}/mathomatic.h

%changelog
* Wed Oct 23 2013 dvaleev@suse.com
- Exclude ppc64 from building. It have failing tests and upstream
  seems not interested in fixing that.
* Tue Sep 11 2012 georgegesslein@gmail.com
- Updated to Mathomatic 16.0.4, only change is to allow
  linking with editline library, instead of readline.
* Sat Sep  8 2012 georgegesslein@gmail.com
- Updated to new, enhanced version: Mathomatic 16.0.3
  All changes are listed at http://mathomatic.org/NEWS
* Mon Aug  6 2012 georgegesslein@gmail.com
- Updated to new bug fix version: Mathomatic 16.0.2
  All changes are listed at http://mathomatic.org/NEWS
* Sun Jul 22 2012 georgegesslein@gmail.com
- Updated to new version: Mathomatic 16.0.1
  All changes are listed at http://mathomatic.org/NEWS
* Fri Jun 29 2012 georgegesslein@gmail.com
- Updated to major new version, Mathomatic 16.0.0
  All changes are listed at http://mathomatic.org/NEWS
* Fri May 25 2012 georgegesslein@gmail.com
- Updated to latest Mathomatic version 15.8.5
  Features more user interface improvements and many bugfixes.
  All changes are listed at http://mathomatic.org/NEWS
* Thu May 10 2012 georgegesslein@gmail.com
- Updated to the latest Mathomatic version 15.8.4
  This release features bug fixes and interface improvements.
  All changes are listed at http://mathomatic.org/NEWS
* Sun Apr 29 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.3
- Added matho_clear(3) man page.
- All other changes are listed at http://mathomatic.org/NEWS
* Sat Mar 24 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.2
  This release fixes regressions and other bugs.
  All changes are listed at http://mathomatic.org/NEWS
* Fri Mar  9 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.1
  This is a bugfix release
- Removed unnecessary INSTALL_PROGRAM=install from mathomatic.spec
- All other changes are listed at http://mathomatic.org/NEWS
* Sat Feb 18 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.8.0.
  This is a bugfix release.
  All changes are listed at http://mathomatic.org/NEWS
* Wed Feb  1 2012 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.3.
  All changes are listed at http://mathomatic.org/NEWS
- Author's secondary email address changed from "gesslein@linux.com"
  to "gesslein@mathomatic.org".
* Wed Dec 14 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.2.
  All changes are listed at http://mathomatic.org/NEWS
* Tue Nov 22 2011 cfarrell@suse.com
- Use SPDX format (http://www.spdx.org/licenses). Also, the package is
  LGPL-2.1 only
* Fri Nov 18 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.1.
  All changes are listed here: http://mathomatic.org/NEWS
* Wed Nov  2 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.7.0.
- Removed requirement for gnuplot.  (How do I suggest gnuplot?)
- All other changes are listed here: http://mathomatic.org/NEWS
* Sun Sep 25 2011 georgegesslein@gmail.com
- Updated to Mathomatic version 15.6.5.
  All changes are listed here: http://mathomatic.org/changes.txt
* Wed Aug 24 2011 georgegesslein@gmail.com
- Updated to version 15.6.4.
  All changes are listed here: http://mathomatic.org/changes.txt
* Thu Aug  4 2011 georgegesslein@gmail.com
- Updated to version 15.6.3.
* Sun Jun 12 2011 georgegesslein@gmail.com
- Remove requirement of time command availability.
* Sun Jun 12 2011 georgegesslein@gmail.com
- Updated to version 15.6.2 with corrected makefile.
* Sun Jun  5 2011 georgegesslein@gmail.com
- Updated to version 15.6.1
- Now installing m4/functions.m4 to proper directory
* Thu May 12 2011 georgegesslein@gmail.com
- RPM spec file corrections and cleanup
- added devel subpackage
* Sat Apr 30 2011 georgegesslein@gmail.com
- Update to version 15.6.0.  Removed default stripping of
  mathomatic executable.
* Tue Apr 19 2011 georgegesslein@gmail.com
- Update to version 15.5.3, added m4 Mathomatic.
* Mon Apr 18 2011 georgegesslein@gmail.com
- 15.5.2-3, added Prime Number Tools to install, in case someone
  wants them.  These are small, integer math utilities.
* Thu Apr 14 2011 georgegesslein@gmail.com
- 15.5.2-2, respect RPM_OPT_FLAGS
* Mon Mar 21 2011 georgegesslein@gmail.com
- Update to version 15.5.2
* Thu Mar 10 2011 georgegesslein@gmail.com
- Update to version 15.5.1.
* Sat Mar  5 2011 georgegesslein@gmail.com
- 15.5.0-3, a few fixes, fixed 64-bit build failures.
* Sat Mar  5 2011 georgegesslein@gmail.com
- 15.5.0-2, added Mathomatic static library install.
- Added mathomatic.desktop file, still doesn't seem to be in a
  proper category, but it is now completely configurable.
* Fri Feb 25 2011 georgegesslein@gmail.com
- New upstream version 15.5.0, with many ease-of-use enhancements.
- Stripped mathomatic executable.
* Fri Feb 18 2011 georgegesslein@gmail.com
- 15.4.4-3, Created this file "mathomatic.changes".
* Mon Feb 14 2011 georgegesslein@gmail.com
- Mathomatic version 15.4.4, Initial package.
